@@ -1,5 +1,5 @@
 package Data::TableReader::Decoder::TSV;
-$Data::TableReader::Decoder::TSV::VERSION = '0.002';
+$Data::TableReader::Decoder::TSV::VERSION = '0.003';
 use Moo 2;
 use Try::Tiny;
 use Carp;
@@ -12,7 +12,7 @@ extends 'Data::TableReader::Decoder::CSV';
 
 sub _build_parser {
 	my $args= shift->_parser_args || {};
-	Data::TableReader::Decoder::CSV->_csv_class->new({
+	Data::TableReader::Decoder::CSV->default_csv_module->new({
 		binary => 1,
 		allow_loose_quotes => 1,
 		auto_diag => 2,
@@ -36,7 +36,7 @@ Data::TableReader::Decoder::TSV - Access rows of a tab-delimited text file
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
